@@ -21,4 +21,7 @@ InvalidMulticlassLabel = register_exception('InvalidMulticlassLabel', 'Detect mu
 InvalidOneClassLabel = register_exception('InvalidOneClassLabel', 'Found 1 class only in label, please check it')
 InvalidBinaryLabel = register_exception('InvalidBinaryLabel', 'Invalid binary value label, please check it')
 DiscreteException = register_exception('DiscreteException', 'Discrete number is required for this variable')
-IterableException = register_exception('IterableException', 'This variable must be a type of list/dataframe/series/ or numpy array')
\ No newline at end of file
+IterableException = register_exception('IterableException', 'This variable must be a type of list/dataframe/series/ or numpy array')
+SameSizeException = register_exception('SameSizeException', 'Same size is expected')
+NanValueException = register_exception('NanValueException', 'Included Nan value exception, must not be Nan')
+InvalidParameter = register_exception('InvalidParameter', 'Invalid parameter provided, check again')
\ No newline at end of file
