@@ -19,11 +19,7 @@ import sklearn
 from sklearn.metrics import roc_curve
 
 
-
-config_file = Path(__file__).parent / "config.yaml"
-config = yaml.load(config_file.open(mode='r'),Loader=yaml.FullLoader)
-
-THRESHOLD_MONTHLY_GINI = config['THRESHOLD_MONTHLY_GINI']
+THRESHOLD_MONTHLY_GINI = 0.25
 
 
 def _check_iterable(y):
